@@ -20,9 +20,9 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-cd $(dirname $0)/..
+cd "$(dirname $0)/.."
 for po in po/*.po
 do
   # Remove #~ lines
-  msgattrib --no-obsolete -o $po $po
+  msgattrib --no-obsolete -o "$po" "$po"
 done
