@@ -21,8 +21,8 @@
 #
 
 # Update translation files
-cd $(dirname $0)/..
+cd "$(dirname $0)/.."
 for po in po/*.po
 do
-  msgmerge --backup none -U $po po/pdfarranger.pot
+  msgmerge --backup none -U "$po" po/pdfarranger.pot
 done
