@@ -1,4 +1,4 @@
-VERSION='1.7.0'
+VERSION='1.8.2'
 
 from cx_Freeze import setup, Executable
 import os
@@ -6,6 +6,7 @@ import sys
 import distutils
 import shutil
 import glob
+import pkg_resources
 
 include_files = [
     ('data/pdfarranger.ui', 'share/pdfarranger/pdfarranger.ui'),
@@ -123,6 +124,20 @@ addfile("lib/gdk-pixbuf-2.0/2.10.0/loaders.cache")
 addfile("share/glib-2.0/schemas/gschemas.compiled")
 addicons()
 
+
+# Add support for pikepdf.__version__
+distrib = pkg_resources.get_distribution('pikepdf')
+from_path = os.path.join(distrib.egg_info, 'INSTALLER')
+to_path = os.path.join('lib', os.path.basename(distrib.egg_info), 'INSTALLER')
+include_files.append((from_path, to_path))
+
+
+# gspawn-helper is needed for website link in AboutDialog
+from_path = os.path.join(sys.prefix, 'bin', 'gspawn-win64-helper.exe')
+to_path = 'gspawn-win64-helper.exe'
+include_files.append((from_path, to_path))
+
+
 build_options = dict(
     packages=['gi', 'packaging', 'pikepdf'],
     excludes=['tkinter', 'test'],
